[![PyPI](https://img.shields.io/pypi/v/hikari-toolbox)](https://pypi.org/project/hikari-toolbox)
[![Documentation Status](https://readthedocs.org/projects/hikari-toolbox/badge/?version=latest)](https://hikari-toolbox.readthedocs.io/en/latest/?badge=latest)

# hikari-toolbox
Utility functions for [hikari](https://github.com/hikari-py/hikari), a Discord API wrapper.

## Installation
To install toolbox, run the following command:
```sh
python3 -m pip install -U hikari-toolbox
```
To check if toolbox has successfully installed or not, run the following:
```sh
python3 -m toolbox
```

## Usage
For a full reference of all the utilites available with toolbox, please see the [Documentation](https://hikari-toolbox.readthedocs.io/en/latest/index.html)!